#
# spec file for package python-pyqtgraph
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without  test
%{?sle15_python_module_pythons}
Name:           python-pyqtgraph
Version:        0.13.7
Release:        3.1
Summary:        Scientific Graphics and GUI Library for Python
License:        MIT
URL:            https://www.pyqtgraph.org/
# test data is only in the GitHub archive
Source:         https://github.com/pyqtgraph/pyqtgraph/archive/refs/tags/pyqtgraph-%{version}.tar.gz
# PATCH-FIX-OPENSUSE - Borrowed from Fedora - https://src.fedoraproject.org/rpms/python-pyqtgraph/tree/
# Upstream issue: https://github.com/pyqtgraph/pyqtgraph/issues/2644
Patch1:         no-sphinx-qt-doc.patch
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module numpy >= 1.17}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pydata-sphinx-theme}
BuildRequires:  %{python_module qt5 >= 5.12}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros >= 20210628
BuildRequires:  python3-Sphinx
BuildRequires:  python3-sphinx-autodoc-typehints
BuildRequires:  python3-sphinx-qt-documentation
Requires:       python-numpy >= 1.17
Requires:       (python-qt5 >= 5.12 or python-PyQt6 >= 6.1)
Recommends:     python-colorcet
Recommends:     python-cupy
Recommends:     python-h5py
Recommends:     python-numba
Recommends:     python-opengl
Recommends:     python-scipy
BuildArch:      noarch
# Tests fauil. These arches should get the noarch package
ExcludeArch:    %arm %ix86 aarch64
%if %{with test}
BuildRequires:  %{python_module PyQt6 >= 6.1}
BuildRequires:  %{python_module h5py}
BuildRequires:  %{python_module matplotlib-qt}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module opengl}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest-xvfb}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
# Tests fail
#BuildRequires:  python3-pyside6
%endif
%python_subpackages

%description
A pure-Python graphics library for PyQt/PySide/PyQt5/PySide2

PyQtGraph is intended for use in mathematics / scientific / engineering
applications. It is written in pure python, but the library leverages
numpy for number crunching, Qt's GraphicsView framework for 2D display,
and OpenGL for 3D display.

%package -n %{name}-doc
Summary:        Documentation for %{name}
Provides:       %{python_module %{name} = %{version}}

%description -n %{name}-doc
Documentation and help files for %{name}

%prep
%setup -q -n pyqtgraph-pyqtgraph-%{version}
%autopatch -p1
# Fix rpmlint
chmod a-x pyqtgraph/examples/Symbols.py
# only a handful of example scripts have interpreter lines, remove all, they don't have executable bits
sed -i '1{/^#!/ d}' pyqtgraph/examples/*.py
# fix eol encoding
sed -i 's/\r//' pyqtgraph/examples/DateAxisItem_QtDesigner.ui
# gcc calls, but not properly marked as script
chmod -x pyqtgraph/examples/verlet_chain/make

%build
%pyproject_wheel

%install
%pyproject_install

pushd doc
make html
rm build/html/.buildinfo build/doctrees/environment.pickle
popd

mkdir -p %{buildroot}%{_docdir}/%{name}/
cp -r doc/build/html %{buildroot}%{_docdir}/%{name}/
cp -r doc/build/doctrees %{buildroot}%{_docdir}/%{name}/
cp -r pyqtgraph/examples %{buildroot}%{_docdir}/%{name}/

%{python_compileall}
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%fdupes %{buildroot}%{_docdir}/%{name}/

%if %{with test}
%check
# reload happens but is not detected by pytest or pytest-xdist
donttest="test_reload"
%pytest -ra -n auto -k "not (${donttest})"
%endif

%files %{python_files}
%license LICENSE.txt
%exclude %{_docdir}/%{name}/doctrees/
%exclude %{_docdir}/%{name}/examples/
%exclude %{_docdir}/%{name}/html/
%{python_sitelib}/pyqtgraph/
%{python_sitelib}/pyqtgraph-%{version}.dist-info

%files -n %{name}-doc
%license LICENSE.txt
%doc %dir %{_docdir}/%{name}/
%doc %{_docdir}/%{name}/doctrees/
%doc %{_docdir}/%{name}/examples/
%doc %{_docdir}/%{name}/html/

%changelog
* Thu Jun  5 2025 Ben Greiner <code@bnavigator.de>
- Remove pyside2 requirement
- Update qt submodule requirement for matplotlib
- Disable package for ARM and i586 due to failing tests
* Fri May  9 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
* Wed Sep 11 2024 Markéta Machová <mmachova@suse.com>
- update to 0.13.7
  * Optimize clip and downsample
  * Drop python 3.8 and numpy 1.20 support
  * speed up PColorMeshItem
  * NonUniformImage improvements
  * Fix 'import pyqtgraph.canvas' crash
  * Add LabelItem font family option
  * add fastpath for float images with nans
  * Add peegee as mkQApp application icon
  * Add stubs for Qt modules
  * add ColorMapMenu to ColorBarItem
  * bdist_wheel needs to grab peegee icons
  * test_PolyLineROI now passes on non-AMD64 platforms
  * Add note about NaN to int conversion
  * remove functions.try_fastpath_argb as it triggered segfaults
  * Allow users to specify FillRule for FillBetweenItem
- Drop merged patches:
  * py3114.patch
  * 2748.patch
* Wed Jul 19 2023 Markéta Machová <mmachova@suse.com>
- Add upstream patch py3114.patch to fix build with Python 3.11.4+
* Tue Jun 20 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- update to version 0.13.3:
  * https://github.com/pyqtgraph/pyqtgraph/releases/tag/pyqtgraph-0.13.3
- Changelog of skipped 0.13.2:
  * https://github.com/pyqtgraph/pyqtgraph/releases/tag/pyqtgraph-0.13.2
- Re-enable test_rescaleData and add patch to fix it on aarch64:
  * 2748.patch
- Update no-sphinx-qt-doc.patch
* Tue Feb 21 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- update to version 0.13.1:
  * Bug Fixes
    + Refactor examples using `Interactor` to run on changing
    function parameters by @ntjess in
    https://github.com/pyqtgraph/pyqtgraph/pull/2437
  * API Change
    + deprecate GraphicsObject::parentChanged method by @pijyoi
    in https://github.com/pyqtgraph/pyqtgraph/pull/2420
  * Other
    + Move Console to generic template and make font Courier New
    by @j9ac9k in https://github.com/pyqtgraph/pyqtgraph/pull/2435
- Changelog of skipped 0.13.0:
  * https://github.com/pyqtgraph/pyqtgraph/compare/pyqtgraph-0.12.4...pyqtgraph-0.13.0
- Disable test_rescaleData on aarch64 until fixed upstream
- Add patch to not build sphinx qt doc as it fails:
  * no-sphinx-qt-doc.patch
* Thu Jun 23 2022 Arun Persaud <arun@gmx.de>
- update to version 0.12.4:
  * Highlights:
    + #2055 Jupyter Support via jupyter-rfb
    + #2011 Experimental High Performance With Lines > 1px Thickness
    + #2059/#2153 Python 3.10 Support
  * New Features:
    + #2041 Allow unsetting various options in PlotDataItem and
    PlotCurveItem
    + #2052 PlotItem Average pen and shadow pen are now accessible
    + #2090 More coninient methods for color maps and bars
  * Performance Enhancements:
    + #2023 PColorMeshItem Performance Improvements
    + #2032 Speed up PlotCurveItem fillLevel
    + #2036 Speed up arrayToQPath for connect='all' with non-finite
    values
    + #2111 PlotCurveItem OpenGL avoid automatic conversion from
    float64 to float32
    + #2124 Go back to using np.clip on Windows with numpy 1.22 or
    newer
    + #2131 Avoid PyOpenGL automatic array conversion
    + #2198 Cache values used in GraphicsWidget .boundingRect() and
    .shape() methods
    + #2199 Avoid unnecessary call to viewRange if autoRange is
    disabled
    + #2202 Cachce ViewBox view pixel size
  * Bug Fixes:
    + #2034 Fix Mouse Event possitioning issue with grid
    + #2047 Fixed WidgetGroup Handling QSplitter
    + #2054 Limit ViewBox based on double precision limitations
    + #2085 Reverse coordinates when drawing on row-major images
    + #2087 Fix broken imports in some examples
    + #2089 Don't raise exception when close method of an
    already-closed dock is called
    + #2101 Change GroupParameterItem palette to look ok in darkmode
    on macOS
    + #2103 Fix stuck ColorBarItem
    + #2132 Workaround for PySide6 6.2.2 breaking change
    + #2130 RangeColorMapItem derives from ColorMapParameter
    + #2147 Fire correct signal for Checklist ParameterItem type
    + #2148 Avoid comparing a string with a np.ndarray
    + #2170 Fix formatting on minimum value of GradientLegend
  * API/Behavior Changes:
    + #2081 Separate x and y flags for AxisItem.setLogMode
    + #2086 ParameterTree PenParameter now uses GrouParameter instead
    of popup button
    + #2097 Add a proxy delay to checklist ParameterItem changes via
    children edits
    + #2192 Added option to makeARGB to disable masking NaNs
  * Other:
    + #1915 Deprecate QtWidgets accessed through QtGui
    + #2002 isort and pycln prun over entire repo
    + #2038 Fixed various deprecations
    + #2045 Examples Directory moved inside project directory
    + #2051 Implement Pickle Protocol for RemoteGraphicsView
    + #2053 Disable unneeded call to ViewBox.prepareForPaint()
    + #2057 Avoid re-dispatching mouse events from the AxisItem
    + #2064 Add a quantization limit to ViewBox
    + #2073 Implementing glInfo without PyOpenGL
    + #2077 Improved error message for invalid PYQTGRAPH_QT_LIB
    + #2083 Added check for ROI to make sure its in a GraphicsScene
    + #2093 Add helpful exceptions for invalid inputs to some methods
    + #2096 Be lazier about importing h5py
    + #2098 Remove polluting import namespace using *
    + #2099 Convert == None to is None checks
    + #2100 Avoid re-using variables in nested loops
    + #2124 Fixed variety of deprecation warnings
    + #2154 Fix typos and formatting errors in comments/docstrings
    + #2194 stop using deprecated numpy.fromstring and use
    numpy.frombuffer instead
* Sat Jan 22 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.12.3
  * Highlights:
  - PlotCurveItem render speed is now substantially faster
  - #1868/#1873 Example app now has filter text input
  - #1910 PlotSpeedTest now has parameter tree control panel
  * New Features:
  - #1844 More parameter item types (File, Calendar, ProgressBar,
    Font, Pen, Slider)
  - #1865 Matplotlib colormaps viridis, plasma, magma and inferno
    are now included in pyqtgraph
  - #1911 Extend Colormap with HSL cycles and subset generation
  - #1932 Make anti-aliasing optional for paintGL in
    PlotCurveItem
  - #1944 Expand use of QColor functions/methods, including
    setNamedColor
  - #1952 Add checklist parameter item
  - #1998 ThreadTrace can now save to a file
  * Performance Enhancement:
  - #1927 Reduce ColorMap inefficiencies
  - #1956 use QByteArray as backing store in arrayToQPath
  - #1965 perform arrayToQPath in chunks
  * Bug Fixes:
  - #1845 Fix zoom behavior with showGrid by separating mouse
    events stolen by AxisItem
  - #1860 RemoteGraphicsView and RemoteSpeedTest now work under
    windows venv environments
  - #1865 Fixed matplotlib colormap importer code
  - #1869 Fix ColorBarItem tick position on export
  - #1871 Allow adding items to GLViewWidget before showing plot
  - #1875 Fix calls in mouse methods in GLViewWidgets due to
    missing event.localPos() in PyQt6
  - #1876 Fix for improper placement of ROI handle positions in
    some cases
  - #1889/#2003 Fix call to drawText in GLTextItem and
    GLGradientLegendItem on Python 3.10
  - #1897/#1902 Re-enable "experimental" feature with fix for
    PlotCurveItem with OpenGL on Windows
  - #1907 Fix GLVolumeItem example for arm64 platforms
  - #1909 Check if AxisItem.label is None before and exit early
    in resizeEvent
  - #1920 arrayToQPath can handle empty paths
  - #1936 QPolygonF creation can now handle empty arrays
  - #1968 Fix output of clip_array in colormap.modulatedBarData
    not being assigned
  - #1973 Fix PlotItem.updateDecimate unhiding intentionally
    hidden curves
  - #1974 Fix ImageView levelMode with levelMode == 'rgba'
  - #1987 Fix HistogramLUTItem itemChanged with use of autoLevel
  - #2009 Fix ROI curves hidding in ImageView
  * API/Behavior Changes:
  - #1992 Reverted to traditional log10 mode for PlotDataItem
  - #1840 Allow border=False in GraphicsLayout
  - #1846 Reduced pollution to pg.namespace
  - #1853 ColorMap.getColors and getStops behavior changes
  - #1864 Draw GradientLegend in ViewBox coordinates
  - #1885 Raise TypeError instead of general Exception if
    functions.eq is unable to determine equality
  - #1903 Cleanup GLViewWidget
  - #1908 More readable parameters for ColorBarItem
  - #1914 Emit deprecation warning for use of pyqtgraph.ptime
  - #1928 Restore previous signature of TargetItem.setPos
  - #1940 fix log mode by reverting to previous formulation
  - #1954 Deprecate use of values opt for list parameter type
  - #1995 ColorButton now takes optional padding argument instead
    of hardcoded value of 6
  * Other:
  - #1862/#1901 MetaArray now under deprecation warning, to be
    removed in a future version
  - #1892 Add GLPainterItem Example
  - #1844 Debugged elusive intermitted CI segfault
  - #1870/#1891 Updated README.md
  - #1895 Update CONTRIBUTING.md
  - #1913 Bump sphinx and theme versions
  - #1919 Re-organize paramtypes
  - #1935 Remove some unused imports
  - #1939 Remove usage of python2_3.py
  - #1941 Remove str casting of QTextEdit.toPlainText output
  - #1942 Add EOF newline to files missing it
  - #1943 Remove python2 code paths
  - #1951 Fix typos in docs
  - #1957 Bump minimum numpy version to 1.18
  - #1968 Fix ImageView calling deprecated QGraphicsItem.scale()
  - #1985 delegate float LUTs to makeARGB with warning
  - #2014 Replace couple absolute imports with relative imports
- Do not enable pyside6 yet: tests fail
* Wed Sep  1 2021 Ben Greiner <code@bnavigator.de>
- Use github archive for tests
  * remove test-data-8.tar.gz: It has been moved to the main repo
    gh#pyqtgraph/pyqtgraph#1807
- Fix rpmlint
  * remove spurious executable bits and interpreter lines from
    examples
- Update requirements
  * Ensure that it does not build on Leap by requiring
    python-base >= 3.7
  * Allow and test PyQt6 and PySide2 backend
- Don't test OpenGL on ARM because Qt uses unsupported OpenGL ES
* Mon Aug 30 2021 Fusion Future <qydwhotmail@gmail.com>
- Update to 0.12.2:
  * Qt6 6.0 support has been removed in favor of Qt6 6.1+
  * More numba utilization, specifically for makeARGB
  * Substantial ImageItem performance improvements have been made
  * Significant performance improvements made to ScatterPlotItem
    and LinePlots
  * More ColorMap features/support
- Changes since 0.12.0:
  * Qt < 5.12, Python < 3.7, and NumPy < 1.17 are no longer
    supported.
  * For full changelog (huge) since 0.12.0 see
    https://github.com/pyqtgraph/pyqtgraph/blob/master/CHANGELOG
- Update test data version to 8.
* Thu Feb 11 2021 Ben Greiner <code@bnavigator.de>
- Update to version 0.11.1
  * For full changelog (huge) since 0.10.0 see
    https://github.com/pyqtgraph/pyqtgraph/blob/master/CHANGELOG
  * 0.11 is the last feature release to support Python 2 and PyQt4
  * PySide2 support
- Enable test suite with test data
  * construct git repo from test-data-7.tar.gz
- Project adopted NEP 29 for next release. Drop python36 build
  now, because there is no python36-{numpy,scipy} in TW anymore.
* Fri May 18 2018 jengelh@inai.de
- Trim bias from description.
* Thu May 17 2018 bwiedemann@suse.com
- Drop environment.pickle from rpm to make build reproducible
* Wed May  9 2018 toddrme2178@gmail.com
- Use license tag
* Tue Aug 22 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix rpmlint issues
- Fix shebangs
* Mon Nov  7 2016 termim@gmail.com
- Update to 0.10.0
  * New Features:
  - PyQt5 support
  - Options for interpreting image data as either row-major or col-major
  - InfiniteLine and LinearRegionItem can have attached labels
  - DockArea:
  - Dock titles can be changed after creation
  - Added Dock.sigClosed
  - Added TextItem.setColor()
  - FillBetweenItem supports finite-connected curves (those that exclude
    nan/inf)
  * API / behavior changes:
  - Improved ImageItem performance for some data types by scaling LUT
    instead of image
  - Change the defaut color kwarg to None in TextItem.setText() to avoid
    changing the color every time the text is changed.
  - FFT plots skip first sample if x-axis uses log scaling
  - Multiprocessing system adds bytes and unicode to the default list of
    no-proxy data types
  - Version number scheme changed to be PEP440-compliant (only affects
    installations from non-release git commits)
  * Bugfixes:
  - Fix for numpy API change that caused casting errors for inplace operations
  - Fixed git version string generation on python3
  - Fixed setting default values for out-of-bound points in
    pg.interpolateArray
  - Fixed plot downsampling bug on python 3
  - Fixed invalid slice in ImageItem.getHistogram
  - DockArea:
  - Fixed adding Docks to DockArea after all Docks have been removed
  - Fixed DockArea save/restoreState when area is empty
  - Properly remove select box when export dialog is closed using window
    decorations
  - Remove all modifications to python builtins
  - Better Python 2.6 compatibility
  - Fix SpinBox decimals
  - Fixed numerous issues with ImageItem automatic downsampling
  - Fixed PlotItem average curves using incorrect stepMode
  - Fixed TableWidget eating key events
  - Prevent redundant updating of flowchart nodes with multiple inputs
  - Ignore wheel events in GraphicsView if mouse interaction is disabled
  - Correctly pass calls to QWidget.close() up the inheritance chain
  - ColorMap forces color inputs to be sorted
  - Fixed memory mapping for RemoteGraphicsView in OSX
  - Fixed QPropertyAnimation str/bytes handling
  - Fixed __version__ string update when using `setup.py install` with
    newer setuptools
  * Maintenance:
  - Image comparison system for unit testing plus tests for several
    graphics items
  - Travis CI and coveralls/codecov support
  - Add examples to unit tests
* Fri Dec 11 2015 mardnh@gmx.de
- Update to version 0.9.10
  * No changelog available
* Sun Nov 24 2013 p.drouand@gmail.com
- Update to version 0.9.8
  + No changelog available
- Remove useless CFLAGS definition
- README.txt is not provided anymore by upstream
* Sat Apr 20 2013 toddrme2178@gmail.com
- Remove unneeded python(abi) requires
* Thu Apr 18 2013 toddrme2178@gmail.com
- Update to 0.9.7
  * No changelog
- Add python 3 version
* Thu Nov 29 2012 toddrme2178@gmail.com
- Initial spec file
